# Installation

Install and update using [pip](https://pip.pypa.io/en/stable/getting-started/):

```shell
pip install trackteroid
```

## Python Version

We recommend using the latest version of Python. Trackteroid supports Python 3.7 and newer.

## Dependencies

These distributions will be installed automatically when installing Trackteroid.

- [ftrack-python-api](https://pypi.org/project/ftrack-python-api/): This is the Python client for the ftrack API
- [wrapt](https://pypi.org/project/wrapt/): Module for decorators, wrappers and monkey patching